
DeNova Safelock
---------------

Locks are usually the simplest way to get safe concurrent access to a shared resource.
But they are a bear to get right. Safelock makes it easy. Get simple systemwide
multithread, multiprocess, and multiprogram safe locks.


Full Description
----------------

Learn more about [DeNova Safelock](https://denova.com/open_source/safelock/)

Install Safelock's systemd [service file](https://denova.com/open_source/safelock/get_app/safelock.service)
to ensure your python apps can easily and safely be locked. If you are installing
Safelock from github, be sure to also install the "safelog" package from PyPI.
